/**
******************************************************************************
* @file    IRPyro_API_multi_device_layer.c
* @author  _KEMET Ltd.
* @date    March 2018
* @version Release 1.0.6
* @copyright (c) 2018 _KEMET, Ltd
* @brief   IRPyro Application interface functions implementation
*
* @verbatim
 ===============================================================================
                      ##### How to use this driver #####
 ===============================================================================
      [..]
       (#) Make sure that IRPyro_LIST_SIZE is big enough for your list
       (#) Declare an IRPyro_list_type variable in your code
       (#) Declare as many IRPyro_sensor_device_type variables as IRPyros sensors
           on the list.
       (#) Fill the values for CS, INT and address for each IRPyro
       (#) Fill the values for number_of_active_channels and read_mode
       (#) AFE, CCP and WUP can be left empty if desired, configuration macros
           will fill them with default values
       (#) Call IRPyro_open() to commit the values to the physical IRPyro
       (#) IRPyro_read() retrieves the values sampled by the IRPyro sensor
       (#) Modify the IRPyro settings using IRPyro_IOCTL()
       (#) Close the device when finished using IRPyro_read()
   @endverbatim
******************************************************************************
   @attention <h2><center>&copy; COPYRIGHT 2018 _KEMET, Ltd</center></h2>
   @verbatim
    Copyright (c) 2018, _KEMET, Ltd
    All rights reserved.

    THIS SOFTWARE IS PROVIDED BY _KEMET, Ltd ''AS IS'' AND ANY
    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL _KEMET, Ltd BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   @endverbatim
******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "Version.h"
#include "IRPyro_API_single_device_layer.h"
#include "IRPyro_API_multi_device_layer.h"
/* Private functions  ---------------------------------------------------------*/
/**
  * @defgroup IRPyro_multi IRPyro multiple device layer
    * @brief Extends the functionality of the basic IRPyro functions (Open, Close and Read) by applying them sequentially to a list of devicesLIST
  * @ingroup IRPyro_API
  * @{
  */
/** @defgroup LIST_IRPyro Multiple device layer Initialization and Configuration functions
 *  @brief   Manipulates a LIST of IRPyro devices
 *  @verbatim
 ===============================================================================
           ##### Initialization and Configuration functions #####
 ===============================================================================
    [..] This section provides a set of functions allowing to initialize a LIST
         by taking individual IRPyro sensor and setting AFE, CCP and WUP
         registers and I2C address.
    @endverbatim
  * @{
  */
/**
 * @defgroup IRPyro_list_type_functions IRPyro multi device functions
 * @brief Extends Open, Read and Close to a group of IRPyro devices
 * @{
 */
/**
  * @brief  initializes a group of IRPyro sensors
  * @param  this_list  pointer to the IRPyro list data structure
  * @param  list_size  number of elements in the list
  * @retval op_result  1 success / 0 error
  */
uint8_t IRPyro_open_devices(IRPyro_devices this_list, uint8_t list_size)
{
    uint8_t op_result = 0;
    for(uint8_t idx=0; idx<list_size; ++idx)
    {
        op_result += IRPyro_open(&this_list[idx]);
    }
    return (op_result == list_size ? 1:0); // 1 success / 0 error
}

/**
  * @brief  Collects data from the IRPyro group
  * @param  this_list pointer to the IRPyro data structure
  * @param  list_size  number of elements in the list
  * @retval op_result 1 success / 0 error
  */
uint8_t IRPyro_read_devices(IRPyro_devices this_list, uint8_t list_size)
{
    uint8_t op_result = 0;
    for(uint8_t idx=0; idx<list_size; ++idx)
    {
        op_result += IRPyro_read(&this_list[idx]);
    }
    return (op_result == list_size ? 1:0); // 1 success / 0 error
}

/**
  * @brief  Stops streaming, deallocates memory and disable the IRPyro sensor
  * @param  this_list pointer to the IRPyro data structure
  * @param  list_size  number of elements in the list
  * @retval None
  */
uint8_t IRPyro_close_devices(IRPyro_devices this_list, uint8_t list_size)
{
    uint8_t op_result = 0;
    for(uint8_t idx=0; idx<list_size; ++idx)
    {
        op_result += IRPyro_close(&this_list[idx]);
    }
    return (op_result == list_size ? 1:0); // 1 success / 0 error
}
/**
  * @brief  access to IRPyro registers
  * @param  this_list pointer to the IRPyro data structure
  * @param  list_size  number of elements in the list
  * @param  cmd pointer to command data structure
  * @param  arg argument data structure
  * @retval 1 success / 0 fail
  */
uint8_t IRPyro_ioctl_devices(IRPyro_devices this_list, uint8_t list_size, IRPyro_cmd_type* cmd, IRPyro_arg_type arg)
{
    uint8_t op_result = 0;
    for(uint8_t idx=0; idx<list_size; ++idx)
    {
        op_result += IRPyro_ioctl(&this_list[idx], cmd, arg);
    }
    return (op_result == list_size ? 1:0); // 1 success / 0 error
}

/** end of IRPyro multi device functions
 * @}
 */
/** end Multiple device layer Initialization and Configuration functions
 * @}
 */
/** end IRPyro multiple device layer
 * @}
 */
/* ********** Copyright (c) 2018 _KEMET, Ltd. **********END OF FILE************/
